@@ -6,6 +6,6 @@ function fullcalendar_dashboard_render() {
 		return blog_render ();
 	}
 	
-	return "<p class=\"ulicms_error\">$mainFile fehlt!</p>";
+	return "<p class=\"ulicms-error\">$mainFile fehlt!</p>";
 }
 ?>
